==> istio-model-v1beta1-6.5.1-sources.jar: io/fabric8/istio/api/security/v1beta1/JWTHeaderFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JWTHeaderFluentImpl<A extends JWTHeaderFluent<A>> extends BaseFluent<A> implements JWTHeaderFluent<A>{
  public JWTHeaderFluentImpl() {
  }
  public JWTHeaderFluentImpl(JWTHeader instance) {
    this.withName(instance.getName()); 
    this.withPrefix(instance.getPrefix()); 
  }
  private String name;
  private String prefix;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getPrefix() {
    return this.prefix;
  }
  public A withPrefix(String prefix) {
    this.prefix=prefix; return (A) this;
  }
  public Boolean hasPrefix() {
    return this.prefix != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    JWTHeaderFluentImpl that = (JWTHeaderFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (prefix != null ? !prefix.equals(that.prefix) :that.prefix != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  prefix,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (prefix != null) { sb.append("prefix:"); sb.append(prefix); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.7.0-sources.jar: io/fabric8/istio/api/security/v1beta1/JWTHeaderFluentImpl.java <==
package io.fabric8.istio.api.security.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JWTHeaderFluentImpl<A extends JWTHeaderFluent<A>> extends BaseFluent<A> implements JWTHeaderFluent<A>{
  public JWTHeaderFluentImpl() {
  }
  public JWTHeaderFluentImpl(JWTHeader instance) {
    if (instance != null) {
      this.withName(instance.getName());
      this.withPrefix(instance.getPrefix());
    }
  }
  private String name;
  private String prefix;
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getPrefix() {
    return this.prefix;
  }
  public A withPrefix(String prefix) {
    this.prefix=prefix; return (A) this;
  }
  public Boolean hasPrefix() {
    return this.prefix != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JWTHeaderFluentImpl that = (JWTHeaderFluentImpl) o;
    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(prefix, that.prefix)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  prefix,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (prefix != null) { sb.append("prefix:"); sb.append(prefix); }
    sb.append("}");
    return sb.toString();
  }
  
}
